/**
 * JASMINe
 * Copyright (C) 2011 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JmxConnection.java 7394 2011-01-04 16:33:37Z danesa $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.probe.jmxconnection.api;

import java.io.IOException;
import java.util.Map;

import javax.management.MBeanServerConnection;

/**
 * @author danesa
 * JmxConnection Service interface.
 */
public interface JmxConnection {


    /**
     * Create a connector client for the connector target server at the given targetUrl
     * and try to connect the client.
     * @param targetName name of the target
     * @param targetUrl jmx url for the target
     * @param env properties for connector creation
     * @throws JmxConnectionExceptionThrown if connector could not be created, contains the cause.
     */
    void createConnector(final String targetName, final String targetUrl, final Map<String, Object> env) throws JmxConnectionException;

    /**
     * Closes the client connection with the target server
     * @param target target name
     */
    void closeConnector(String target) throws IOException;

    /**
     * Return a MBeanServerConnection object for a target identified by a name.
     * @param target target name
     * @return connection object
     * @exception IOException There is no valid MBeanServerConnection for the target
     */
    MBeanServerConnection getConnection(String target) throws IOException;

}
